Print method for summary.lphom objects
# S3 method for summary.lphom
print(x, ..., margins = TRUE, digits = 2)An summary.lphom class object.
Other arguments passed on to methods. Not currently used.
A TRUE/FALSE argument informing if the margins of the matrix should be displayed. Default TRUE.
Integer indicating the number of decimal places to be shown. Default, 2.